==============
pdfreactor-api
==============

Python API for PDFreactor (https://www.pdfreactor.com), a HTML-to-PDF processor.

This distribution package is based on the original API module by RealObjects.
To make use of it, you need

- a license key (from RealObjects; see https://www.pdfreactor.com/buy/)
- a running PDFreactor server.

